'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
  /**
   * Listen for scans inside Dryrain Technologies' Enterprise Browser with specified characteristics
   * @param  {String} scanOptions.barcodePrefix
   * @param  {RegExp} scanOptions.barcodeValueTest - RegExp defining valid scan value (not including prefix).
   * @param  {Function} scanHandler - called with the results of the scan
   * @return {Function} - removes this listener when called
   */
  onScan: function onScan() {
    var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    var barcodePrefix = _ref.barcodePrefix;
    var barcodeValueTest = _ref.barcodeValueTest;
    var scanHandler = arguments[1];

    if (!_lodash2.default.isString(barcodePrefix)) {
      throw new TypeError('barcodePrefix must be a string');
    }
    if (!(barcodeValueTest instanceof RegExp)) {
      throw new TypeError('barcodeValueTest must be a regular expression');
    }
    if (!_lodash2.default.isFunction(scanHandler)) {
      throw new TypeError('scanHandler must be a function');
    }

    /**
     * Dryrain Technologies' Enterprise Browser calls this function, if defined, whenever a barcode is scanned
     * within the app.  API documentation is not publicly available. See http://dryraintechnologies.com.
     */
    if (!_lodash2.default.isFunction(window.DT_DecoderDataResponse)) {
      window.DT_DecoderDataResponse = function (barcode) {
        // eslint-disable-line camelcase
        window.DT_DecoderDataResponse.scanHandlers.forEach(function (handler) {
          return handler(barcode);
        });
        return true;
      };
      window.DT_DecoderDataResponse.scanHandlers = [];
    }

    var dryrainHandler = function dryrainHandler(barcode) {
      if (barcode.match('^' + barcodePrefix) !== null) {
        var barcodeValue = barcode.slice(barcodePrefix.length);
        if (barcodeValueTest.test(barcodeValue)) {
          scanHandler(barcodeValue);
        }
      }
    };

    window.DT_DecoderDataResponse.scanHandlers.push(dryrainHandler);

    var removeListener = function removeListener() {
      var dryrainHandlerIndex = window.DT_DecoderDataResponse.scanHandlers.indexOf(dryrainHandler);
      if (dryrainHandlerIndex >= 0) {
        window.DT_DecoderDataResponse.scanHandlers.splice(dryrainHandlerIndex, 1);
      }
    };

    return removeListener;
  }
}; /* eslint-env browser */

module.exports = exports['default'];